# edge-ai

`edge-ai` is a python package and CLI to transform data into hardware-agnostic, embedded AI models, using the Edge Impulse API.

Full documentation for this package is available at https://docs.edgeimpulse.com/notebooks/edge-ai